
# typed: ignore
# frozen_string_literal: true

module Setsuzoku
  module Credential
    extend T::Sig
    extend T::Helpers
    extend Forwardable
    interface!

    attr_accessor :auth_strategy
    def_delegators :@auth_strategy, :plugin

    # All auth actions that are implemented.
    #
    # @return [Hash] all auth endpoint definitions for the API.
    sig { abstract.returns(T::Hash[T.untyped, T.untyped]) }
    def auth_actions; end

    # Create a stub implementation of the credential for testing purposes
    #
    # @return [Struct] a struct that implements stubbed version of a credential's required methods.
    sig { abstract.returns(Struct) }
    def self.stub_credential; end

    # The status of the credential.
    #
    # @return [Hash] the status of the credential.
    sig { abstract.returns(String) }
    def status; end

    # Setter for the status of the credential.
    #
    # @return [Hash] the status of the credential.
    sig { abstract.params(val: T.nilable(String)).returns(String) }
    def status=(val); end

    # A settings object for the credential.
    #
    # @return [Hash] the settings for the credential.
    sig { abstract.returns(T.nilable(T::Hash[T.untyped, T.untyped])) }
    def settings; end

    # Setter for the settings object for the credential.
    #
    # @param val [Hash] a settings object to set.
    #
    # @return [Hash] the settings for the credential.
    sig do
      abstract
          .params(val: T.nilable(T::Hash[T.untyped, T.untyped]))
          .returns(T.nilable(T::Hash[T.untyped, T.untyped]))
    end
    def settings=(val); end
  end
end


