# typed: false
# frozen_string_literal: true

module Setsuzoku
  module Service
    # The Token-based API Authentication Interface definition.
    # Any Plugin that implements this must implement all methods defined here.
    #
    # Defines all necessary methods for handling authentication for any token-based authentication.
    module WebService

      class AuthStrategy
        include Setsuzoku::AuthStrategy
        extend T::Sig
        extend T::Helpers
        abstract!

        # The authorization headers that need to be defined for this authentication strategy.
        #
        # @return [Hash(String)] the authorization key/values needed for authentication.
        sig { abstract.returns(T::Hash[Symbol, T.untyped]) }
        def auth_headers;end

        # These are interface methods that a plugin that implements this strategy must implement.
        module InterfaceMethods
          extend T::Sig
          extend T::Helpers
          abstract!

        end
      end
    end
  end
end

