# typed: strict
# frozen_string_literal: true

module Setsuzoku
  module Service
    module WebService
      module Credentials
        module BasicAuthCredential
          extend T::Sig
          extend T::Helpers
          include Setsuzoku::Credential
          abstract!

          # The username to use for the credential.
          #
          # @return [String] the credential's token.
          sig{ abstract.returns(T.nilable(String)) }
          def username; end

          # The username to set for the credential.
          #
          # @return [String] the credential's token to set.
          #
          sig{ abstract.params(val: String).returns(T.nilable(String)) }
          def username=(val); end

          # The password to use for the credential.
          #
          # @return [String] the credential's token.
          sig{ abstract.returns(T.nilable(String)) }
          def password; end

          # The password to set for the credential.
          #
          # @return [String] the credential's token to set.
          #
          sig{ abstract.params(val: String).returns(T.nilable(String)) }
          def password=(val); end

          # Stub a basic_auth_credential-like instance.
          #
          # @return [Struct] a stubbed basic_auth_credential-like struct.
          sig { returns(Struct) }
          def self.stub_credential
            s = Struct.new(:auth_strategy, :status, :settings, :username, :password)
            s.new(nil, 'active', {}, 'stubbed_username', 'stubbed_password')
          end
        end
      end
    end
  end
end