# typed: ignore
# frozen_string_literal: true

module Setsuzoku
  module Service
    module WebService
      # WebService's Service should define all available auth and api strategies.
      class Service
        extend T::Sig
        extend T::Helpers
        include Setsuzoku::Service

        # The api and auth strategies available for WebService.
        #
        # @return [Hash(Hash(Class))] the available_strategies object for WebService.
        sig { override.returns(T::Hash[Symbol, T::Hash[Symbol, Class]]) }
        def self.available_strategies
          {
            auth: {
                basic: Setsuzoku::Service::WebService::AuthStrategies::BasicAuthStrategy,
                custom: Setsuzoku::Service::WebService::AuthStrategies::CustomAuthStrategy,
                o_auth: Setsuzoku::Service::WebService::AuthStrategies::OAuthStrategy
            },
            api: {
                rest:  ApiStrategies::RestStrategy
            }
          }
        end
      end
    end
  end
end